@@ -46,7 +46,7 @@ required_tags =
 commands = {}
 yaml_found = false
 
-conf_dirs = 'D:/bld/libignition-tools1_1635518506801/_h_env/Library/share/ignition/'
+conf_dirs = 'D:/bld/libignition-tools1_1638468453066/_h_env/Library/share/ignition/'
 conf_dirs = ENV['IGN_CONFIG_PATH'] if ENV.key?('IGN_CONFIG_PATH')
 conf_dirs = conf_dirs.split(';')
 
@@ -282,17 +282,10 @@ if ARGV.include?('--versions')
 end
 
 # Start Backward before loading plugins
-backward_library_name = if (/darwin/ =~ RUBY_PLATFORM).nil?
-                          'ignition-tools-backward.dll'
-                        else
-                          # On macOS, the full path to the library since
-                          # DYLD_LIBRARY_PATH may not work.
-                          'D:/bld/libignition-tools1_1635518506801/work/build/src/ignition-tools-backward.dll'
-                        end
 begin
-  SharedLibInterface::Importer.dlload backward_library_name
+  SharedLibInterface::Importer.dlload 'D:/bld/libignition-tools1_1638468453066/_h_env/Library/lib/ignition-tools-backward.dll'
 rescue SharedLibInterface::DLError
-  puts "Library error: #{backward_library_name} not found. Improved backtrace"\
+  warn 'Library error: D:/bld/libignition-tools1_1638468453066/_h_env/Library/lib/ignition-tools-backward.dll not found. Improved backtrace'\
        ' generation will be disabled'
 end
 
